stalker.db.mixin.StatusMixinDB
==============================

.. inheritance-diagram::
     stalker.db.mixin.StatusMixinDB
     :parts: 1

.. currentmodule:: stalker.db.mixin

.. autoclass:: StatusMixinDB
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StatusMixinDB.setup
   
   

   
   
   